tethysts
==================================

This git repository contains the tethys time series main class for accessing S3 time series data.

The documentation for the package can be found here: `<https://tethysts.readthedocs.io>`_
